import { NextResponse, type NextRequest } from 'next/server';
import { getURL } from './lib/utils';

/**
 * Permet de créer un middleware Next.js qui sera exécuté avant chaque requête.
 *
 * @param req - La requête Next.js
 */
export async function middleware(req: NextRequest) {
  const res = NextResponse.next();

  const token = req.cookies.get('token')?.value;

  if (token) {
    const response = await fetch(`${process.env.NEXT_PUBLIC_API_URL}/player/`, {
      headers: {
        Authorization: `Bearer ${token}`
      },
      cache: 'no-cache',
      next: {
        revalidate: 60
      }
    });

    if (response.status !== 200) {
      res.cookies.set('token', '', {
        path: '/',
        expires: new Date(0)
      });

      NextResponse.redirect(getURL('/sign-in'));
    }
  }

  if (!token && req.nextUrl.pathname.includes('dashboard')) {
    return NextResponse.redirect(getURL('/sign-in'));
  }

  if (token && req.nextUrl.pathname.includes('sign')) {
    return NextResponse.redirect(getURL('/dashboard'));
  }

  return res;
}

export const config = {
  matcher: [
    // On exclut les routes de l'API, les fichiers statiques, les images, les assets, le favicon et le service worker.
    '/((?!api|_next/static|_next/image|assets|favicon|sw.js).*)'
  ]
};
